@@ -46,18 +46,21 @@ class ApplicationClient:
 
         self.suggested_params = suggested_params
 
-    def compile_approval(self) -> tuple[bytes, SourceMap]:
+    def compile_approval(self, source_map: bool = False) -> tuple[bytes, SourceMap]:
         approval_result = self.client.compile(
-            self.app.approval_program, source_map=True
-        )
-        return (
-            b64decode(approval_result["result"]),
-            SourceMap(approval_result["sourcemap"]),
+            self.app.approval_program, source_map=source_map
         )
+        src_map = None
+        if source_map:
+            src_map = SourceMap(approval_result["sourcemap"])
+        return (b64decode(approval_result["result"]), src_map)
 
-    def compile_clear(self) -> tuple[bytes, SourceMap]:
+    def compile_clear(self, source_map: bool = False) -> tuple[bytes, SourceMap]:
         clear_result = self.client.compile(self.app.clear_program, source_map=True)
-        return (b64decode(clear_result["result"]), SourceMap(clear_result["sourcemap"]))
+        src_map = None
+        if source_map:
+            src_map = SourceMap(clear_result["sourcemap"])
+        return (b64decode(clear_result["result"]), src_map)
 
     def create(
         self,
@@ -331,7 +334,7 @@ class ApplicationClient:
             name = method_arg.name
             if name in kwargs:
                 thing = kwargs[name]
-                if type(thing) is dict:
+                if type(thing) is dict and hints.structs is not None:
                     if name in hints.structs:
                         thing = [
                             thing[field_name]
@@ -341,7 +344,7 @@ class ApplicationClient:
                         # todo error if wrong keys
                         thing = list(thing.values())
                 args.append(thing)
-            elif name in hints.resolvable:
+            elif hints.resolvable is not None and name in hints.resolvable:
                 args.append(self.resolve(hints.resolvable[name]))
             else:
                 raise Exception(f"Unspecified argument: {name}")
@@ -413,7 +416,7 @@ class ApplicationClient:
             name = method_arg.name
             if name in kwargs:
                 args.append(kwargs[name])
-            elif name in hints.resolvable:
+            elif hints.resolvable is not None and name in hints.resolvable:
                 args.append(self.resolve(hints.resolvable[name]))
             else:
                 raise Exception(f"Unspecified argument: {name}")
@@ -441,7 +444,9 @@ class ApplicationClient:
 
         return atc
 
-    def get_application_state(self, force_str=False) -> dict[str, str | int]:
+    def get_application_state(
+        self, force_str=False
+    ) -> dict[bytes | str, bytes | str | int]:
         """gets the global state info for the app id set"""
         app_state = self.client.application_info(self.app_id)
         if "params" not in app_state or "global-state" not in app_state["params"]:
@@ -450,7 +455,7 @@ class ApplicationClient:
 
     def get_account_state(
         self, account: str = None, force_str: bool = False
-    ) -> dict[str, str | int]:
+    ) -> dict[str | bytes, bytes | str | int]:
 
         """gets the local state info for the app id set and the account specified"""
 
@@ -533,12 +538,13 @@ class ApplicationClient:
             return self.sender
 
         signer = self.get_signer(signer)
+
         match signer:
-            case AccountTransactionSigner():
+            case AccountTransactionSigner():  # type: ignore
                 return address_from_private_key(signer.private_key)
-            case MultisigTransactionSigner():
+            case MultisigTransactionSigner():  # type: ignore
                 return signer.msig.address()
-            case LogicSigTransactionSigner():
+            case LogicSigTransactionSigner():  # type: ignore
                 return signer.lsig.address()
 
         raise Exception("No sender provided")
