@@ -179,13 +179,13 @@ def test_compile():
     client = get_client()
     ac = ApplicationClient(client, app)
 
-    approval_program, approval_map = ac.compile_approval()
+    approval_program, approval_map = ac.compile_approval(source_map=True)
     assert len(approval_program) > 0, "Should have a valid approval program"
     assert approval_program[0] == version, "First byte should be the version we set"
     assert approval_map.version == 3, "Should have valid source map with version 3"
     assert len(approval_map.pc_to_line) > 0, "Should have valid mapping"
 
-    clear_program, clear_map = ac.compile_clear()
+    clear_program, clear_map = ac.compile_clear(source_map=True)
     assert len(clear_program) > 0, "Should have a valid clear program"
     assert clear_program[0] == version, "First byte should be the version we set"
     assert clear_map.version == 3, "Should have valid source map with version 3"
